capture log close
log using Table1.log, text replace

********* GOVERNMENT EXPENDITURE ON VAN PANCHAYATS (FOREST COUNCILS) **********
use vpexp_by_gov, clear
egen expFPI = sum(actual_exp)
label variable expFPI "Govt expenditure on Forest Panchayat Inspectors in Kumaun in 2002-03 "
scalar exp_FPI = expFPI[1]
display "Govt expenditure on Forest Panchayat Inspectors in Kumaun in 2002-03 = " exp_FPI 
scalar expFPIperha = exp_FPI/(2019*100) 
/* This is from utta_Vp_list03.xls. */
display "FPI Exp on VP's in Kumaun per hectare in 2002-03  = " expFPIperha

********* VAN PANCHAYATS' OWN EXPENDITURE (SURVEY DATA) *********
use vi_large, clear
keep viid vphect vprec_ac vpdirha tot_hh civil vp
gen area_ha__ = vphect
replace area_ha__ = vprec_ac*.4047 if (area_ha__==. | area_ha__==0) & vprec_ac > 0 & vprec_ac < .
replace area_ha__ = vpdirha if (area_ha__==. | area_ha__==0) & vpdirha > 0 & vpdirha < .
keep viid area_ha__ tot_hh civil vp
sort viid
tempfile area
save area, replace

use vpmgmt_wage, clear /* BRING IN WATCHMAN WAGE DATA */
rename vi_id viid
sort viid
merge viid using area 
tab _merge
drop if _merge==1
drop if _merge==2
drop if civil==1 | vp==2
drop civil vp
drop _merge
drop if watch==.
tab watch

gen watch_exp_yr =  (315/287)*(ann_watch_wage + ann_hh_contn*tot_hh)
label variable watch_exp_yr "Expenditure on watchmen inflated to 2002 for non-Kuti data"
/* Ag labour index from priceindextables.html */
tab watch_exp_yr

append using vpexpenses /* KUTI VALLEY DATA */
replace watch = 1 if watch==. & watch_exp_yr > 0 /* watch_exp_yr is not missing in Kuti */
replace watch = 0 if watch==. & watch_exp_yr==0 
summ watch

gen byte guard = watch==1 | rotation==1 | (rotation==. & af_meet > 1 & af_meet < .)
summ guard
scalar watch_freq = r(mean)
dis "Frequency of guarding (watchman or rotation) is " watch_freq

**** Calculate mean and standard error of guarding cost per ha ****
gen watch_perha = watch_exp_yr/area_ha__
label variable watch_perha "Watchmen's wages per ha"
summ watch_perha if watch_perha>0
scalar cm_watch_perha = r(mean)
scalar c_N = r(N)

scalar m_watch_perha = watch_freq*cm_watch_perha
scalar var_watch_perha = watch_freq*68*68 + watch_freq*(1-watch_freq)*(cm_watch_perha^2)
scalar se_watch_perha = (var_watch_perha/(c_N/watch_freq))^0.5
dis se_watch_perha
display "Mean guarding cost per ha by VP's = " m_watch_perha
display "Standard error of guarding cost per ha = " se_watch_perha
******************

summ area_ha__
scalar hectarage = r(mean)
summ other_yr 
scalar m_other_yr = r(mean)
scalar sd_other_yr = r(sd)
scalar n_other_yr = r(N)
display "Average annual other expenditure by VP's = " m_other_yr 

scalar othercost_perha = m_other_yr/hectarage
display "VP's other average annual expenditure per ha = " othercost_perha
scalar se_m_vpOtherCostPerHa = sd_other_yr/((n_other_yr^0.5)*hectarage)
display "VP's S.E. of other average annual expenditure per ha = " se_m_vpOtherCostPerHa
scalar m_vpOwnCostPerHa = m_watch_perha + othercost_perha
display "VP's own average annual expenditure per ha = " m_vpOwnCostPerHa
display "FPI Exp on VP's in Kumaun per hectare in 2002-03  = " expFPIperha

scalar VPcostPerHa = m_vpOwnCostPerHa + expFPIperha 
dis "Total Exp on VPs per ha = " VPcostPerHa

***** EXPENDITURES ON RESERVED (i.e. STATE) FORESTS IN 2002-03 ***********

scalar RFcostperha = 528.33 /* From forest_divn_2002_03.xls, cell Z16  */
display "FD cost per hectare = " RFcostperha
display "Ratio of RF cost to mean VP cost (per ha) = " RFcostperha/VPcostPerHa

********** SAVINGS FROM COUNCIL CONTROL AS PERCENT OF FIREWOOD CONSUMPTION *******
drop _all
use wilima_nss
gen fireconsnratio = vfire/(hhs*pcte)
gen pcfireannual = vfire*12/hhs
svymean pcfireannual, subpop(if district>4 & district<9)
scalar meanpcfireannual = r(estimate)*315/304
display "Mean Value of firewood consumption per person 2002 Rs = " meanpcfireannual

svymean fireconsnratio, subpop(if district>4 & district<9)
scalar meanfcratio = .0304961
display "Value of firewood as propn of consn = " meanfcratio

svytotal pcte fireconsnratio
svymean pcte, subpop(if district>4 & district<9)
scalar meanpcte =  598.0807
scalar realpcte2002rs = meanpcte*(315/304)*12
display "1999-2000 annual per capita expenditure in 2002 rs = " realpcte2002rs
* scalar popdrf = 5.412466998   /* From utta_vp_list03.xls */
* display "Persons per hectare of RF = " popdrf
*display "Savings per person = " (RFcostperha - VPcostPerHa)/popdrf
*display "Savings per person as percentage of per capita expenditure = " ((RFcostperha - VPcostPerHa)/popdrf)*100/realpcte2002rs
scalar RFarea = 3976.986 /* In sq km from forest_divn_2002_03.xls */
scalar totalpop = 2263360 /* from utta_Vp_list03.xls (2001) */
scalar total_savings =  (RFcostperha - VPcostPerHa)*RFarea*100
display "Total savings = " total_savings
display "Savings as percentage of value of firewood consn = " (total_savings*100)/(meanpcfireannual*totalpop)
scalar PFarea =  2019.44801 + 450.28489 /* In sq km from utta_Vp_list03.xls */
scalar RFareaprop = RFarea/(RFarea + PFarea)
display "Savings as % of value of RF firewood prodn = " (total_savings*100)/(meanpcfireannual*totalpop*RFareaprop)

log close
clear
