version 8
capture log close
set more off
log using Tables_S1&S2&S3&4.log, text replace

use cipfrfall_stock_nohat2hr, clear

***** NUMBER OF VILLAGES *****
codebook id if rfdum==0 /* Decentralization text p. 4 */
******************************
gen pcfor = pcbl + pcpi
label variable pcfor "Percentage of polygon that is forest or scrub"
gen Narea = Nrfarea + Npfarea + Ncfarea
gen Npfrfstock = Npfstock + Nrfstock 
gen popdcu = popdsq*popdensity
drop if Nstock==0

summ area_ha if vpdum==1|rfdum==1 /* In text of paper */

bysort vpdum cidum: summ blarea_ha if blarea_ha > .25
bysort vpdum cidum: summ piarea_ha if piarea_ha > .25

ttest asp = 0.5 if cidum==1

********** TABLE S1 ************************
#delimit ;
bysort vpdum cidum: summarize area_ha ccbl ccpi pcfor pcbl pcpi 
asp blasp piasp altk blaltk pialtk popdensity rdist Npfstock Nrfstock Ncfstock Nstock Npfarea Nrfarea Ncfarea ;
preserve ;
drop if cidum==1 ;
sort va_num id ;

********** TABLE S2 ************************ ;
xi: ivreg ccbl i.va_num blasp popdensity popdsq rdist rdistsq
(Npfstock Nrfstock Ncfstock = Npfarea Nrfarea Ncfarea) if rfdum==1 & blarea_ha > .25, r cl(id)  ;

xi: ivreg ccbl i.va_num blasp popdensity popdsq rdist rdistsq
(Npfstock Nrfstock Ncfstock = Npfarea Nrfarea Ncfarea) if vpdum==1 & blarea_ha > .25, r cl(id) ;

xi: ivreg ccpi i.va_num piasp popdensity popdsq rdist rdistsq (Npfstock Nrfstock Ncfstock = Npfarea Nrfarea Ncfarea) 
if rfdum==1 & piarea_ha > .25, r cl(id)  ;

xi: ivreg ccpi i.va_num piasp popdensity popdsq rdist rdistsq
(Npfstock Nrfstock Ncfstock = Npfarea Nrfarea Ncfarea) if vpdum==1 & piarea_ha > .25, r cl(id) ;

*************** TABLE S3 ********************************** ;
foreach X in Npfstock Nrfstock Ncfstock Npfarea Nrfarea Ncfarea popdsq popdcu 
blasp  piasp altk altksq popdensity rdist rdistsq { ;
gen v`X' = vpdum*`X' ;
} ;

xi: ivreg ccbl i.va_num vpdum blasp popdensity popdsq popdcu rdist  
(Npfstock  Nrfstock  Ncfstock  = Npfarea  Nrfarea  Ncfarea) if blarea_ha > 0.25, r cl(id)  ;

xi: ivreg ccpi i.va_num vpdum piasp popdensity popdsq popdcu  
(Npfstock  Nrfstock  Ncfstock  = Npfarea  Nrfarea  Ncfarea) if piarea_ha > 0.25, r cl(id)  ;

*************** TABLE 4 ********************************** ;

xi: ivreg ccbl i.va_num blasp popdensity popdsq popdcu rdist rdistsq  
vpdum vblasp vpopdensity vpopdsq vpopdcu vrdist vrdistsq 
(Npfstock vNpfstock Nrfstock vNrfstock Ncfstock vNcfstock = Npfarea vNpfarea Nrfarea vNrfarea Ncfarea vNcfarea) 
if blarea_ha > 0.25, r cl(id)  ; 
estimates store bl ;
foreach x of varlist blasp popdensity popdsq popdcu rdist rdistsq Npfstock Nrfstock Ncfstock { ;
summ `x' if e(sample) & vpdum==0 ;
scalar `x'_rfbar = r(mean) ;
} ;
lincom vpdum + vblasp*blasp_rfbar + vpopdensity*popdensity_rfbar + vpopdsq*popdsq_rfbar + vpopdcu*popdcu_rfbar
+ vrdist*rdist_rfbar + vrdistsq*rdistsq_rfbar + vNpfstock*Npfstock_rfbar + vNrfstock*Nrfstock_rfbar 
+ vNcfstock*Ncfstock_rfbar;

xi: ivreg ccpi i.va_num piasp popdensity popdsq popdcu rdist rdistsq
vpdum vpiasp vpopdensity vpopdsq vpopdcu vrdist vrdistsq (Npfstock vNpfstock Nrfstock vNrfstock Ncfstock vNcfstock =
Npfarea vNpfarea Nrfarea vNrfarea Ncfarea vNcfarea) if piarea_ha > 0.25, r cl(id)  ; 
estimates store pine ;
*outreg2 bl pine using tableS3, replace label word ;
foreach x of varlist piasp popdensity popdsq popdcu rdist rdistsq Npfstock Nrfstock Ncfstock { ;
summ `x' if e(sample) & vpdum==0 ;
scalar `x'_rfbar = r(mean) ;
} ;
lincom vpdum + vpiasp*piasp_rfbar + vpopdensity*popdensity_rfbar + vpopdsq*popdsq_rfbar + vpopdcu*popdcu_rfbar
+ vrdist*rdist_rfbar + vrdistsq*rdistsq_rfbar + vNpfstock*Npfstock_rfbar + vNrfstock*Nrfstock_rfbar 
+ vNcfstock*Ncfstock_rfbar;

log close

